==> openshift-model-operator-5.7.3-sources.jar: io/fabric8/openshift/api/model/operator/v1/ProxyConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ProxyConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ProxyConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ProxyConfigFluent<A>{
  public ProxyConfigFluentImpl() {
  }
  public ProxyConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.ProxyConfig instance) {
    this.withBindAddress(instance.getBindAddress()); 
    this.withIptablesSyncPeriod(instance.getIptablesSyncPeriod()); 
    this.withProxyArguments(instance.getProxyArguments()); 
  }
  private java.lang.String bindAddress;
  private java.lang.String iptablesSyncPeriod;
  private java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> proxyArguments;
  public java.lang.String getBindAddress() {
    return this.bindAddress;
  }
  public A withBindAddress(java.lang.String bindAddress) {
    this.bindAddress=bindAddress; return (A) this;
  }
  public java.lang.Boolean hasBindAddress() {
    return this.bindAddress != null;
  }
  
  /**
   * Method is deprecated. use withBindAddress instead.
   */
  @java.lang.Deprecated
  public A withNewBindAddress(java.lang.String arg0) {
    return (A)withBindAddress(new String(arg0));
  }
  public java.lang.String getIptablesSyncPeriod() {
    return this.iptablesSyncPeriod;
  }
  public A withIptablesSyncPeriod(java.lang.String iptablesSyncPeriod) {
    this.iptablesSyncPeriod=iptablesSyncPeriod; return (A) this;
  }
  public java.lang.Boolean hasIptablesSyncPeriod() {
    return this.iptablesSyncPeriod != null;
  }
  
  /**
   * Method is deprecated. use withIptablesSyncPeriod instead.
   */
  @java.lang.Deprecated
  public A withNewIptablesSyncPeriod(java.lang.String arg0) {
    return (A)withIptablesSyncPeriod(new String(arg0));
  }
  public A addToProxyArguments(java.lang.String key,java.util.ArrayList<java.lang.String> value) {
    if(this.proxyArguments == null && key != null && value != null) { this.proxyArguments = new java.util.LinkedHashMap<java.lang.String,java.util.ArrayList<java.lang.String>>(); }
    if(key != null && value != null) {this.proxyArguments.put(key, value);} return (A)this;
  }
  public A addToProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map) {
    if(this.proxyArguments == null && map != null) { this.proxyArguments = new java.util.LinkedHashMap<java.lang.String,java.util.ArrayList<java.lang.String>>(); }
    if(map != null) { this.proxyArguments.putAll(map);} return (A)this;
  }
  public A removeFromProxyArguments(java.lang.String key) {
    if(this.proxyArguments == null) { return (A) this; }
    if(key != null && this.proxyArguments != null) {this.proxyArguments.remove(key);} return (A)this;
  }
  public A removeFromProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map) {
    if(this.proxyArguments == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.proxyArguments != null){this.proxyArguments.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> getProxyArguments() {
    return this.proxyArguments;
  }
  public <K,V>A withProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> proxyArguments) {
    if (proxyArguments == null) { this.proxyArguments =  null;} else {this.proxyArguments = new java.util.LinkedHashMap<java.lang.String,java.util.ArrayList<java.lang.String>>(proxyArguments);} return (A) this;
  }
  public java.lang.Boolean hasProxyArguments() {
    return this.proxyArguments != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProxyConfigFluentImpl that = (ProxyConfigFluentImpl) o;
    if (bindAddress != null ? !bindAddress.equals(that.bindAddress) :that.bindAddress != null) return false;
    if (iptablesSyncPeriod != null ? !iptablesSyncPeriod.equals(that.iptablesSyncPeriod) :that.iptablesSyncPeriod != null) return false;
    if (proxyArguments != null ? !proxyArguments.equals(that.proxyArguments) :that.proxyArguments != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bindAddress,  iptablesSyncPeriod,  proxyArguments,  super.hashCode());
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ProxyConfigFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.ArrayList;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ProxyConfigFluentImpl<A extends io.fabric8.openshift.api.model.operator.v1.ProxyConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.operator.v1.ProxyConfigFluent<A>{
  public ProxyConfigFluentImpl() {
  }
  public ProxyConfigFluentImpl(io.fabric8.openshift.api.model.operator.v1.ProxyConfig instance) {
    this.withBindAddress(instance.getBindAddress()); 
    this.withIptablesSyncPeriod(instance.getIptablesSyncPeriod()); 
    this.withProxyArguments(instance.getProxyArguments()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String bindAddress;
  private java.lang.String iptablesSyncPeriod;
  private java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> proxyArguments;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getBindAddress() {
    return this.bindAddress;
  }
  public A withBindAddress(java.lang.String bindAddress) {
    this.bindAddress=bindAddress; return (A) this;
  }
  public java.lang.Boolean hasBindAddress() {
    return this.bindAddress != null;
  }
  
  /**
   * Method is deprecated. use withBindAddress instead.
   */
  @java.lang.Deprecated
  public A withNewBindAddress(java.lang.String arg0) {
    return (A)withBindAddress(new String(arg0));
  }
  public java.lang.String getIptablesSyncPeriod() {
    return this.iptablesSyncPeriod;
  }
  public A withIptablesSyncPeriod(java.lang.String iptablesSyncPeriod) {
    this.iptablesSyncPeriod=iptablesSyncPeriod; return (A) this;
  }
  public java.lang.Boolean hasIptablesSyncPeriod() {
    return this.iptablesSyncPeriod != null;
  }
  
  /**
   * Method is deprecated. use withIptablesSyncPeriod instead.
   */
  @java.lang.Deprecated
  public A withNewIptablesSyncPeriod(java.lang.String arg0) {
    return (A)withIptablesSyncPeriod(new String(arg0));
  }
  public A addToProxyArguments(java.lang.String key,java.util.ArrayList<java.lang.String> value) {
    if(this.proxyArguments == null && key != null && value != null) { this.proxyArguments = new java.util.LinkedHashMap<java.lang.String,java.util.ArrayList<java.lang.String>>(); }
    if(key != null && value != null) {this.proxyArguments.put(key, value);} return (A)this;
  }
  public A addToProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map) {
    if(this.proxyArguments == null && map != null) { this.proxyArguments = new java.util.LinkedHashMap<java.lang.String,java.util.ArrayList<java.lang.String>>(); }
    if(map != null) { this.proxyArguments.putAll(map);} return (A)this;
  }
  public A removeFromProxyArguments(java.lang.String key) {
    if(this.proxyArguments == null) { return (A) this; }
    if(key != null && this.proxyArguments != null) {this.proxyArguments.remove(key);} return (A)this;
  }
  public A removeFromProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> map) {
    if(this.proxyArguments == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.proxyArguments != null){this.proxyArguments.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> getProxyArguments() {
    return this.proxyArguments;
  }
  public <K,V>A withProxyArguments(java.util.Map<java.lang.String,java.util.ArrayList<java.lang.String>> proxyArguments) {
    if (proxyArguments == null) { this.proxyArguments =  null;} else {this.proxyArguments = new java.util.LinkedHashMap<java.lang.String,java.util.ArrayList<java.lang.String>>(proxyArguments);} return (A) this;
  }
  public java.lang.Boolean hasProxyArguments() {
    return this.proxyArguments != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProxyConfigFluentImpl that = (ProxyConfigFluentImpl) o;
    if (bindAddress != null ? !bindAddress.equals(that.bindAddress) :that.bindAddress != null) return false;
    if (iptablesSyncPeriod != null ? !iptablesSyncPeriod.equals(that.iptablesSyncPeriod) :that.iptablesSyncPeriod != null) return false;
    if (proxyArguments != null ? !proxyArguments.equals(that.proxyArguments) :that.proxyArguments != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(bindAddress,  iptablesSyncPeriod,  proxyArguments,  additionalProperties,  super.hashCode());
  }
  
}
